@@ -749,30 +749,21 @@ class APNSResponse(object):
     Attributes:
         tokens (list): List of all tokens sent during bulk sending.
         message (APNSMessage): :class:`APNSMessage` object sent.
-        errors (list): List of APNS exceptions for each failed token.
         failures (list): List of all failed tokens.
         successes (list): List of all successful tokens.
-        token_errors (dict): Dict mapping the failed tokens to their respective
-            APNS exception.
 
     .. versionadded:: 1.0.0
     """
 
-    def __init__(self, tokens, message, errors):
+    def __init__(self, tokens, message, failures):
         self.tokens = tokens
         self.message = message
-        self.errors = errors
         self.failures = []
         self.successes = []
-        self.token_errors = {}
-
-        for err in errors:
-            tok = tokens[err.identifier]
-            self.failures.append(tok)
-            self.token_errors[tok] = err
 
         self.successes = [token for token in tokens
-                          if token not in self.failures]
+                          if token not in failures]
+        self.failures = failures
 
 
 class APNSExpiredToken(namedtuple('APNSExpiredToken', ['token', 'timestamp'])):
@@ -987,7 +978,6 @@ class APNSHTTP2Client(object):
         if not isinstance(ids, (list, tuple)):
             ids = [ids]
 
-        unsendable_devices = []
         if max_payload_length is None:
             max_payload_length = self.default_max_payload_length
 
@@ -998,16 +988,17 @@ class APNSHTTP2Client(object):
         validate_tokens(ids)
         validate_message(message, max_size=APNS_HTTP2_MAX_NOTIFICATION_SIZE)
 
+        failures = []
         for device_id in ids:
 
             try:
                 self._send(
                     device_id=device_id, message=message,
                     low_priority=low_priority, expiration=expiration)
-            except Exception:
-                unsendable_devices.append(device_id)
+            except APNSError:
+                failures.append(device_id)
 
-        return APNSResponse(tokens=ids, message=message, errors=unsendable_devices)
+        return APNSResponse(tokens=ids, message=message, failures=failures)
 
     def _send(
             self, device_id, message, low_priority,
@@ -1041,11 +1032,10 @@ class APNSHTTP2Client(object):
                 headers=request_headers
             )
             response = self.conn.get_response(stream_id)
-        except Exception as e:
-            raise APNSError(description=str(e))
+        except Exception:
+            raise APNSError()
         if response.status != HttpStatus.OK:
-            raise APNSError(
-                'Invalid status code - {0}'.format(response.status))
+            raise APNSError()
 
         return response
 
